"""Top-level package for geodemoRA."""

__author__ = """Ramendra Sahoo"""
__email__ = 'ramendrageo@gmail.com'
__version__ = '0.0.5'

from .geodemora import *
from .utils import *